use serde::{Deserialize, Serialize};
// use serde_json::Result;
use anyhow::{Context, Result};
use std::collections::HashMap;
use std::fs;
use std::{fs::File, io::Write};

#[derive(Serialize, Deserialize)]
pub struct Configuration {
    pub user_agent: String,
    pub versions: HashMap<String, String>,
}

pub fn read_config(filename: &str) -> Result<Configuration> {
    let data = fs::read_to_string(filename)
        .with_context(|| format!("Failed reading filename {}", filename))?;
    let config: Configuration = serde_json::from_str(&data)?;
    Ok(config)
}

pub fn write_config(filename: &str, config: &Configuration) -> Result<()> {
    let data = serde_json::to_string_pretty(config)?;
    let mut file = File::create(filename)?;
    file.write_all(data.as_bytes())?;
    Ok(())
}
